sqlobject.inheritance.tests.test_aggregates module — SQLObject 3.9.1 documentation

# sqlobject.inheritance.tests.test_aggregates module

class `sqlobject.inheritance.tests.test_aggregates.` `SOTestAggregate1`(**kw)

  Bases: `sqlobject.inheritance.InheritableSQLObject`

  property `childName`
  `j` = so_test_aggregate1
  `q` = so_test_aggregate1
  class `sqlmeta`(instance)

    Bases: `sqlobject.inheritance.InheritableSQLMeta`

    `childClasses` = {'SOTestAggregate2': <class 'sqlobject.inheritance.tests.test_aggregates.SOTestAggregate2'>}
    `childName` = None
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `parentClass` = None
    `soClass`

      alias of `sqlobject.inheritance.tests.test_aggregates.SOTestAggregate1`

    `table` = 'so_test_aggregate1'
  property `value1`

class `sqlobject.inheritance.tests.test_aggregates.` `SOTestAggregate2`(**kw)

  Bases: `sqlobject.inheritance.tests.test_aggregates.SOTestAggregate1`

  property `childName`
  `j` = so_test_aggregate2
  `q` = so_test_aggregate2
  class `sqlmeta`(instance)

    Bases: `sqlobject.declarative.sqlmeta`

    `childClasses` = {}
    `childName` = 'SOTestAggregate2'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `parentClass`

      alias of `sqlobject.inheritance.tests.test_aggregates.SOTestAggregate1`

    `soClass`

      alias of `sqlobject.inheritance.tests.test_aggregates.SOTestAggregate2`

    `table` = 'so_test_aggregate2'
  property `value1`
  property `value2`

`sqlobject.inheritance.tests.test_aggregates.` `test_aggregates`()